
# b1 - baka1

b1 or baka1 is an small, simple Encryption and Decryption Algorithm simple as that.
You are allowed to use it only and only if you agree that **MM is a BaKa**.

If you do agree with this statement, then you are free to do anything with this algorithm.

Have a nice day :)

```

Keep it a secret IAS

```